import java.io.FilterOutputStream;
import java.io.IOException;
import java.io.OutputStream;
import java.io.PrintStream;

/**
 * @author hornick
 * This output stream decorator adds line numbers to a wrapped output stream
 */
public class LineNumberDecorator extends FilterOutputStream {
	private int lineNumber; // 

	/**
	 * constructs the output stream decorator
	 * @param wrappedStream
	 */
	public LineNumberDecorator(OutputStream wrappedStream) {
		super(wrappedStream);
		lineNumber = 0; // initialize line number
	}

	/**
	 * accept an array of bytes and forward them to the wrapped output stream
	 */
	@Override
	public void write( byte[] b ) throws IOException {
		lineNumber++;
		String line = "" + lineNumber + ": ";
		for( int i=0; i<line.length(); i++ ) {
			byte c = (byte)line.charAt(i);
			out.write(c);
		}
		// invoke the wrapped output stream's write() method
		out.write(b);
	}


	/**
	 * accept an array of bytes and forward them to the wrapped output stream
	 */
	@Override
	public void write( byte[] b, int offset, int len ) throws IOException {
		lineNumber++;
		String line = "" + lineNumber + ": ";
		for( int i=0; i<line.length(); i++ ) {
			byte c = (byte)line.charAt(i);
			out.write(c);
		}
		out.write(b, offset, len);
	}


}
